@@ -88,7 +88,7 @@ void extend_ehhs(const int* const data, const int nbr_chr, const int foc_mrk, co
  * Calculates ehhs values in increasing distance to the focal marker
  */
 void calc_ehhs(const int* const data, const int nbr_chr, const int nbr_mrk, const int foc_mrk, const int lim_haplo,
-		const int lim_homo_haplo, const double lim_ehhs, const int phased, int* const tot_nbr_chr_in_hap, double* const ehhs,
+		const int lim_homo_haplo, const double lim_ehhs, const bool phased, int* const tot_nbr_chr_in_hap, double* const ehhs,
 		double* const nehhs) {
 
 	int nbr_hap;                                                   //number of distinct haplotypes
